@@ -12,17 +12,18 @@ groups <- "group"
 colors <- "color"
 fontcolors <- "fontcolor"
 tooltips <- "tooltip"
+optimize_y <- TRUE
 linewidth <- NULL
 title <- NULL
 showLabels <- NULL
 show_labels <- TRUE
 lineInterval <- NULL
 background_lines <- 10
-data <- vistime:::validate_input(dat, start, end, events, groups, linewidth, title, showLabels, show_labels, lineInterval, background_lines)
+data <- vistime:::validate_input(dat, start, end, events, groups, tooltips, optimize_y, linewidth, title, showLabels, show_labels, lineInterval, background_lines)
 data <- vistime:::set_colors(data, colors, fontcolors)
 data <- vistime:::fix_columns(data, events, start, end, groups, tooltips)
 data <- vistime:::set_subplots(data)
-data <- vistime:::set_y_values(data)
+data <- vistime:::set_y_values(data, optimize_y)
 ranges <- vistime:::plot_ranges(data, linewidth, show_labels, background_lines)
 events <- vistime:::plot_events(data, show_labels, background_lines)
 generated <- vistime:::plot_glued(data, title, ranges, events)
