@@ -8,6 +8,7 @@ groups <- "group"
 colors <- "color"
 fontcolors <- "fontcolor"
 tooltips <- "tooltip"
+optimize_y <- TRUE
 linewidth <- NULL
 title <- NULL
 showLabels <- NULL
@@ -20,9 +21,10 @@ dat <- data.frame(
   end = c("2019-01-01", "2019-01-10")
 )
 
-dat <- vistime:::validate_input(dat, start, end, events, groups, linewidth, title, showLabels, show_labels, lineInterval, background_lines)
+dat <- vistime:::validate_input(dat, start, end, events, groups, tooltips, optimize_y, linewidth, title, showLabels, show_labels, lineInterval, background_lines)
 dat <- vistime:::set_colors(dat, colors, fontcolors)
 dat <- vistime:::fix_columns(dat, events, start, end, groups, tooltips)
 dat <- vistime:::set_subplots(dat)
 
-test_that("Main test", expect_equal(vistime:::set_y_values(dat)$y, rep(1:2, 2)))
+test_that("Main test", expect_equal(vistime:::set_y_values(dat, optimize_y)$y, rep(1:2, 2)))
+test_that("optimize_y", expect_equal(vistime:::set_y_values(dat, FALSE)$y, as.integer(factor(dat$event))))
